# Generated by roxygen2: do not edit by hand

S3method(as_sf,HexData)
S3method(as_sf,default)
export(as_dggrid)
export(as_sf)
export(as_tibble.HexData)
export(cell_area)
export(cell_to_index)
export(cell_to_lonlat)
export(cell_to_sf)
export(cells)
export(dg_closest_res_to_area)
export(dgearthstat)
export(dggrid_43h_sequence)
export(dggrid_is_compatible)
export(dgverify)
export(from_dggrid)
export(get_children)
export(get_parent)
export(globe_centers)
export(grid_clip)
export(grid_global)
export(grid_info)
export(grid_rect)
export(h3_crosswalk)
export(hex_corners_to_sf)
export(hex_grid)
export(hexify)
export(hexify_area_to_eff_res)
export(hexify_assign)
export(hexify_build_icosa)
export(hexify_cell_id_to_quad_ij)
export(hexify_cell_to_icosa_tri)
export(hexify_cell_to_index)
export(hexify_cell_to_lonlat)
export(hexify_cell_to_plane)
export(hexify_cell_to_quad_ij)
export(hexify_cell_to_quad_xy)
export(hexify_cell_to_sf)
export(hexify_compare_indices)
export(hexify_compare_resolutions)
export(hexify_default_index_type)
export(hexify_eff_res_to_area)
export(hexify_eff_res_to_resolution)
export(hexify_face_centers)
export(hexify_forward)
export(hexify_forward_to_face)
export(hexify_get_children)
export(hexify_get_parent)
export(hexify_get_precision)
export(hexify_get_resolution)
export(hexify_grid)
export(hexify_grid_cell_to_lonlat)
export(hexify_grid_global)
export(hexify_grid_rect)
export(hexify_grid_to_cell)
export(hexify_heatmap)
export(hexify_icosa_tri_to_plane)
export(hexify_icosa_tri_to_quad_ij)
export(hexify_icosa_tri_to_quad_xy)
export(hexify_index_to_cell)
export(hexify_index_to_lonlat)
export(hexify_inverse)
export(hexify_is_valid_index_type)
export(hexify_lonlat_to_cell)
export(hexify_lonlat_to_index)
export(hexify_lonlat_to_plane)
export(hexify_lonlat_to_quad_ij)
export(hexify_projection_stats)
export(hexify_quad_ij_to_cell)
export(hexify_quad_ij_to_icosa_tri)
export(hexify_quad_ij_to_xy)
export(hexify_quad_xy_to_cell)
export(hexify_quad_xy_to_icosa_tri)
export(hexify_resolution_to_eff_res)
export(hexify_roundtrip_test)
export(hexify_set_precision)
export(hexify_set_verbose)
export(hexify_which_face)
export(hexify_z7_canonical)
export(is_hex_data)
export(is_hex_grid)
export(lonlat_to_cell)
export(n_cells)
export(plot_globe)
export(plot_grid)
export(plot_world)
exportClasses(HexData)
exportClasses(HexGridInfo)
exportMethods("$")
exportMethods("$<-")
exportMethods("[")
exportMethods("[[")
exportMethods("[[<-")
exportMethods(as.data.frame)
exportMethods(as.list)
exportMethods(cells)
exportMethods(dim)
exportMethods(grid_info)
exportMethods(n_cells)
exportMethods(names)
exportMethods(ncol)
exportMethods(nrow)
exportMethods(plot)
exportMethods(show)
import(methods)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,adjustcolor)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setValidity)
importFrom(methods,slot)
importFrom(methods,slotNames)
importFrom(methods,validObject)
importFrom(rlang,.data)
importFrom(utils,head)
useDynLib(hexify, .registration = TRUE)
