% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{n_cells}
\alias{n_cells}
\title{Get Number of Cells}
\usage{
n_cells(x)
}
\arguments{
\item{x}{A HexData object}
}
\value{
Integer count of unique cells
}
\description{
Get the number of unique cells in a HexData object.
}
