% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_projection.R
\name{hexify_face_centers}
\alias{hexify_face_centers}
\title{Get icosahedron face centers}
\usage{
hexify_face_centers()
}
\value{
Data frame with 20 rows and columns lon, lat (degrees)
}
\description{
Returns the center coordinates of all 20 icosahedral faces.
}
\examples{
centers <- hexify_face_centers()
plot(centers$lon, centers$lat)
}
\seealso{
Other projection:
\code{\link[=hexify_build_icosa]{hexify_build_icosa()}},
\code{\link[=hexify_forward]{hexify_forward()}},
\code{\link[=hexify_forward_to_face]{hexify_forward_to_face()}},
\code{\link[=hexify_get_precision]{hexify_get_precision()}},
\code{\link[=hexify_inverse]{hexify_inverse()}},
\code{\link[=hexify_projection_stats]{hexify_projection_stats()}},
\code{\link[=hexify_set_precision]{hexify_set_precision()}},
\code{\link[=hexify_set_verbose]{hexify_set_verbose()}},
\code{\link[=hexify_which_face]{hexify_which_face()}}
}
\concept{projection}
