% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{hexify_grid_to_HexGridInfo}
\alias{hexify_grid_to_HexGridInfo}
\title{Convert legacy hexify_grid to HexGridInfo}
\usage{
hexify_grid_to_HexGridInfo(x)
}
\arguments{
\item{x}{A hexify_grid object (S3)}
}
\value{
A HexGridInfo object (S4)
}
\description{
Convert legacy hexify_grid to HexGridInfo
}
\keyword{internal}
