% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_map.R
\name{plot_world}
\alias{plot_world}
\title{Quick world map plot}
\usage{
plot_world(fill = "gray90", border = "gray50", ...)
}
\arguments{
\item{fill}{Fill color for countries}

\item{border}{Border color for countries}

\item{...}{Additional arguments passed to plot()}
}
\value{
NULL invisibly. Creates a plot as side effect.
}
\description{
Simple wrapper to plot the built-in world map.
}
\examples{
# Quick world map
plot_world()

# Custom colors
plot_world(fill = "lightblue", border = "darkblue")
}
\seealso{
Other visualization:
\code{\link[=hexify_heatmap]{hexify_heatmap()}}
}
\concept{visualization}
