% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify-package.R
\docType{package}
\name{hexify-package}
\alias{hexify-package}
\title{hexify}
\description{
Core icosahedron and 'Snyder' projection helpers.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://gillescolling.com/hexify/}
  \item Report bugs at \url{https://github.com/gcol33/hexify/issues}
}

}
\author{
\strong{Maintainer}: Gilles Colling \email{gilles.colling051@gmail.com} (\href{https://orcid.org/0000-0003-3070-6066}{ORCID}) [copyright holder]

Authors:
\itemize{
  \item Gilles Colling \email{gilles.colling051@gmail.com} (\href{https://orcid.org/0000-0003-3070-6066}{ORCID}) [copyright holder]
}

Other contributors:
\itemize{
  \item Uber Technologies, Inc. (H3 C library, src/h3 (Apache-2.0)) [contributor, copyright holder]
}

}
