% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{extract_grid}
\alias{extract_grid}
\title{Extract grid from various objects}
\usage{
extract_grid(x, allow_null = FALSE)
}
\arguments{
\item{x}{Object containing grid info}

\item{allow_null}{If TRUE, return NULL when x is NULL}
}
\value{
HexGridInfo object
}
\description{
Internal function to extract a HexGridInfo from different input types.
Accepts HexGridInfo, HexData, or legacy hexify_grid objects.
}
\keyword{internal}
