% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{HexGridInfo-methods}
\alias{HexGridInfo-methods}
\alias{$,HexGridInfo-method}
\alias{names,HexGridInfo-method}
\alias{show,HexGridInfo-method}
\alias{as.list,HexGridInfo-method}
\title{HexGridInfo S4 Methods}
\usage{
\S4method{$}{HexGridInfo}(x, name)

\S4method{names}{HexGridInfo}(x)

\S4method{show}{HexGridInfo}(object)

\S4method{as.list}{HexGridInfo}(x, ...)
}
\arguments{
\item{x}{HexGridInfo object}

\item{name}{Slot name}

\item{object}{HexGridInfo object (for show)}

\item{...}{Additional arguments}
}
\value{
\itemize{
\item \code{$}: The value of the requested slot
\item \code{names}: Character vector of slot names
\item \code{show}: The object, invisibly (called for side effect of printing)
\item \code{as.list}: A named list of slot values
}
}
\description{
S4 methods for HexGridInfo objects. These provide standard R operations
like \code{$}, \code{names()}, \code{show()}, and \code{as.list()}.
}
\keyword{internal}
