% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_projection.R
\name{hexify_set_verbose}
\alias{hexify_set_verbose}
\title{Set verbose mode for inverse projection}
\usage{
hexify_set_verbose(verbose = TRUE)
}
\arguments{
\item{verbose}{Logical}
}
\value{
Invisible NULL
}
\description{
When enabled, prints convergence information.
}
\seealso{
Other projection:
\code{\link[=hexify_build_icosa]{hexify_build_icosa()}},
\code{\link[=hexify_face_centers]{hexify_face_centers()}},
\code{\link[=hexify_forward]{hexify_forward()}},
\code{\link[=hexify_forward_to_face]{hexify_forward_to_face()}},
\code{\link[=hexify_get_precision]{hexify_get_precision()}},
\code{\link[=hexify_inverse]{hexify_inverse()}},
\code{\link[=hexify_projection_stats]{hexify_projection_stats()}},
\code{\link[=hexify_set_precision]{hexify_set_precision()}},
\code{\link[=hexify_which_face]{hexify_which_face()}}
}
\concept{projection}
