% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_helpers.R
\name{get_children}
\alias{get_children}
\title{Get children cells}
\usage{
get_children(cell_id, grid, levels = 1L)
}
\arguments{
\item{cell_id}{Numeric vector of cell IDs}

\item{grid}{A HexGridInfo or HexData object}

\item{levels}{Number of levels down (default 1)}
}
\value{
List of numeric vectors containing child cell IDs
}
\description{
Returns the child cells at a finer resolution.
}
\keyword{internal}
