% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{cells}
\alias{cells}
\title{Get Cell IDs}
\usage{
cells(x)
}
\arguments{
\item{x}{A HexData object}
}
\value{
A vector of cell IDs
}
\description{
Extract the unique cell IDs present in a HexData object.
}
