% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constructors.R
\name{as_tibble.HexData}
\alias{as_tibble.HexData}
\title{Convert HexData to tibble}
\usage{
as_tibble.HexData(x, ...)
}
\arguments{
\item{x}{A HexData object}

\item{...}{Additional arguments (ignored)}
}
\value{
A tibble
}
\description{
Convert HexData to tibble
}
