% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{is_hex_grid}
\alias{is_hex_grid}
\title{Check if object is HexGridInfo}
\usage{
is_hex_grid(x)
}
\arguments{
\item{x}{Object to check}
}
\value{
Logical
}
\description{
Check if object is HexGridInfo
}
