% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_grid.R
\name{calculate_resolution_for_area}
\alias{calculate_resolution_for_area}
\title{Calculate resolution for target area}
\usage{
calculate_resolution_for_area(
  target_area_km2,
  aperture = 3,
  radius_km = EARTH_RADIUS_KM
)
}
\arguments{
\item{target_area_km2}{Target area in square kilometers}

\item{aperture}{Aperture (3, 4, or 7)}

\item{radius_km}{Radius of the body, in kilometers}
}
\value{
Resolution level
}
\description{
Uses the 'ISEA3H'/'ISEA4H'/'ISEA7H' cell count formula
N = 10 * aperture^res + 2, which matches 'dggridR' resolution numbering
exactly.
}
\keyword{internal}
