% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constructors.R
\name{new_hex_data}
\alias{new_hex_data}
\title{Create a HexData Object (Internal)}
\usage{
new_hex_data(data, grid, cell_id, cell_center)
}
\arguments{
\item{data}{Data frame or sf object (original user data, untouched)}

\item{grid}{HexGridInfo object}

\item{cell_id}{Numeric vector of cell IDs for each row}

\item{cell_center}{Matrix with columns lon, lat for cell centers}
}
\value{
A HexData object
}
\description{
Internal constructor for HexData objects. Users should use \code{hexify()}
instead.
}
\keyword{internal}
