% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_index.R
\name{hexify_area_to_eff_res}
\alias{hexify_area_to_eff_res}
\title{Convert area to effective resolution}
\usage{
hexify_area_to_eff_res(area_km2)
}
\arguments{
\item{area_km2}{Target area in km^2}
}
\value{
Effective resolution (may be fractional)
}
\description{
Finds the effective resolution that gives approximately the target area.
}
\seealso{
Other grid statistics:
\code{\link[=dg_closest_res_to_area]{dg_closest_res_to_area()}},
\code{\link[=dgearthstat]{dgearthstat()}},
\code{\link[=hexify_compare_resolutions]{hexify_compare_resolutions()}},
\code{\link[=hexify_eff_res_to_area]{hexify_eff_res_to_area()}},
\code{\link[=hexify_eff_res_to_resolution]{hexify_eff_res_to_resolution()}},
\code{\link[=hexify_resolution_to_eff_res]{hexify_resolution_to_eff_res()}}
}
\concept{grid statistics}
\keyword{internal}
