% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_index.R
\name{hexify_compare_indices}
\alias{hexify_compare_indices}
\title{Compare two indices}
\usage{
hexify_compare_indices(idx1, idx2)
}
\arguments{
\item{idx1}{First index string}

\item{idx2}{Second index string}
}
\value{
Integer: -1 if idx1 < idx2, 0 if equal, 1 if idx1 > idx2
}
\description{
Lexicographic comparison of two index strings.
}
\seealso{
Other hierarchical index:
\code{\link[=hexify_cell_to_index]{hexify_cell_to_index()}},
\code{\link[=hexify_default_index_type]{hexify_default_index_type()}},
\code{\link[=hexify_get_children]{hexify_get_children()}},
\code{\link[=hexify_get_parent]{hexify_get_parent()}},
\code{\link[=hexify_get_resolution]{hexify_get_resolution()}},
\code{\link[=hexify_index_to_cell]{hexify_index_to_cell()}},
\code{\link[=hexify_index_to_lonlat]{hexify_index_to_lonlat()}},
\code{\link[=hexify_is_valid_index_type]{hexify_is_valid_index_type()}},
\code{\link[=hexify_lonlat_to_index]{hexify_lonlat_to_index()}},
\code{\link[=hexify_z7_canonical]{hexify_z7_canonical()}}
}
\concept{hierarchical index}
\keyword{internal}
