% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hexify_index.R
\name{hexify_default_index_type}
\alias{hexify_default_index_type}
\title{Get default index type for aperture}
\usage{
hexify_default_index_type(aperture)
}
\arguments{
\item{aperture}{Aperture (3, 4, or 7)}
}
\value{
String: "z3", "z7", or "zorder"
}
\description{
Returns the recommended index type:
\itemize{
\item Aperture 3: "z3"
\item Aperture 4: "zorder"
\item Aperture 7: "z7"
}
}
\seealso{
Other hierarchical index:
\code{\link[=hexify_cell_to_index]{hexify_cell_to_index()}},
\code{\link[=hexify_compare_indices]{hexify_compare_indices()}},
\code{\link[=hexify_get_children]{hexify_get_children()}},
\code{\link[=hexify_get_parent]{hexify_get_parent()}},
\code{\link[=hexify_get_resolution]{hexify_get_resolution()}},
\code{\link[=hexify_index_to_cell]{hexify_index_to_cell()}},
\code{\link[=hexify_index_to_lonlat]{hexify_index_to_lonlat()}},
\code{\link[=hexify_is_valid_index_type]{hexify_is_valid_index_type()}},
\code{\link[=hexify_lonlat_to_index]{hexify_lonlat_to_index()}},
\code{\link[=hexify_z7_canonical]{hexify_z7_canonical()}}
}
\concept{hierarchical index}
\keyword{internal}
