% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{HexGridInfo_to_hexify_grid}
\alias{HexGridInfo_to_hexify_grid}
\title{Convert HexGridInfo to legacy hexify_grid}
\usage{
HexGridInfo_to_hexify_grid(x)
}
\arguments{
\item{x}{A HexGridInfo object (S4)}
}
\value{
A hexify_grid object (S3)
}
\description{
For backwards compatibility with existing functions.
}
\keyword{internal}
