% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{grid_info}
\alias{grid_info}
\title{Get Grid Specification}
\usage{
grid_info(x)
}
\arguments{
\item{x}{A HexData object}
}
\value{
A HexGridInfo object
}
\description{
Extract the grid specification from a HexData object.
}
\examples{
df <- data.frame(lon = c(0, 10, 20), lat = c(45, 50, 55))
result <- hexify(df, lon = "lon", lat = "lat", area_km2 = 1000)
grid_spec <- grid_info(result)
}
